@@ -30,7 +30,7 @@ accounts or third party accounts.
 
 package Finance::Bank::IE::PermanentTSB;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use strict;
 use warnings;
@@ -667,14 +667,17 @@ sub logoff {
     my $self = shift;
     my $config_ref = shift;
 
-    my $res = $agent->get($BASEURL . '/online/DoLogOff.aspx');
-    $agent->save_content("./logoff.html") if $config_ref->{debug};
-    $agent->field('__EVENTTARGET', 'lbtnContinue');
-    $agent->submit;
+    if(defined $agent) {
+
+        my $res = $agent->get($BASEURL . '/online/DoLogOff.aspx');
+        $agent->save_content("./logoff.html") if $config_ref->{debug};
+        $agent->field('__EVENTTARGET', 'lbtnContinue');
+        $agent->submit;
+    }
 }
 
 END {
-    logoff if $lastop;
+    logoff;
 }
 
 1;
